==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Input for task that migrates SQL Server databases to Azure SQL Database Managed Instance online scenario.
 * @property azureApp Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
 * @property backupFileShare Backup file share information for all selected databases.
 * @property selectedDatabases Databases to migrate
 * @property sourceConnectionInfo Connection information for source SQL Server
 * @property storageResourceId Fully qualified resourceId of storage
 * @property targetConnectionInfo Connection information for Azure SQL Database Managed Instance
 */
public data class ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs(
    public val azureApp: Output<AzureActiveDirectoryAppArgs>,
    public val backupFileShare: Output<FileShareArgs>? = null,
    public val selectedDatabases: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>,
    public val sourceConnectionInfo: Output<SqlConnectionInfoArgs>,
    public val storageResourceId: Output<String>,
    public val targetConnectionInfo: Output<MiSqlConnectionInfoArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs =
        com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs.builder()
            .azureApp(azureApp.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .backupFileShare(backupFileShare?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .selectedDatabases(
                selectedDatabases.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .sourceConnectionInfo(
                sourceConnectionInfo.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .storageResourceId(storageResourceId.applyValue({ args0 -> args0 }))
            .targetConnectionInfo(
                targetConnectionInfo.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs].
 */
@PulumiTagMarker
public class ValidateMigrationInputSqlServerSqlMISyncTaskInputArgsBuilder internal constructor() {
    private var azureApp: Output<AzureActiveDirectoryAppArgs>? = null

    private var backupFileShare: Output<FileShareArgs>? = null

    private var selectedDatabases: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>? = null

    private var sourceConnectionInfo: Output<SqlConnectionInfoArgs>? = null

    private var storageResourceId: Output<String>? = null

    private var targetConnectionInfo: Output<MiSqlConnectionInfoArgs>? = null

    /**
     * @param value Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
     */
    @JvmName("dokfjkjlgwalxmwh")
    public suspend fun azureApp(`value`: Output<AzureActiveDirectoryAppArgs>) {
        this.azureApp = value
    }

    /**
     * @param value Backup file share information for all selected databases.
     */
    @JvmName("owfnsjwcqmyydtad")
    public suspend fun backupFileShare(`value`: Output<FileShareArgs>) {
        this.backupFileShare = value
    }

    /**
     * @param value Databases to migrate
     */
    @JvmName("canabqdmnswnmujy")
    public suspend
    fun selectedDatabases(`value`: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>) {
        this.selectedDatabases = value
    }

    @JvmName("rbovdtdiafkdvsxk")
    public suspend fun selectedDatabases(
        vararg
        values: Output<MigrateSqlServerSqlMIDatabaseInputArgs>,
    ) {
        this.selectedDatabases = Output.all(values.asList())
    }

    /**
     * @param values Databases to migrate
     */
    @JvmName("ewfgupttwhvlcxvf")
    public suspend
    fun selectedDatabases(values: List<Output<MigrateSqlServerSqlMIDatabaseInputArgs>>) {
        this.selectedDatabases = Output.all(values)
    }

    /**
     * @param value Connection information for source SQL Server
     */
    @JvmName("agxvxoankypjtgdp")
    public suspend fun sourceConnectionInfo(`value`: Output<SqlConnectionInfoArgs>) {
        this.sourceConnectionInfo = value
    }

    /**
     * @param value Fully qualified resourceId of storage
     */
    @JvmName("yxgpjyouwvnyhasd")
    public suspend fun storageResourceId(`value`: Output<String>) {
        this.storageResourceId = value
    }

    /**
     * @param value Connection information for Azure SQL Database Managed Instance
     */
    @JvmName("jmlislorjrntmjrb")
    public suspend fun targetConnectionInfo(`value`: Output<MiSqlConnectionInfoArgs>) {
        this.targetConnectionInfo = value
    }

    /**
     * @param value Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
     */
    @JvmName("meoejlvigludotuc")
    public suspend fun azureApp(`value`: AzureActiveDirectoryAppArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azureApp = mapped
    }

    /**
     * @param argument Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
     */
    @JvmName("fpkpnfwqthnnfbpn")
    public suspend fun azureApp(argument: suspend AzureActiveDirectoryAppArgsBuilder.() -> Unit) {
        val toBeMapped = AzureActiveDirectoryAppArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureApp = mapped
    }

    /**
     * @param value Backup file share information for all selected databases.
     */
    @JvmName("ncgukcyximlkkrdx")
    public suspend fun backupFileShare(`value`: FileShareArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupFileShare = mapped
    }

    /**
     * @param argument Backup file share information for all selected databases.
     */
    @JvmName("fmscqdxnwndotuwm")
    public suspend fun backupFileShare(argument: suspend FileShareArgsBuilder.() -> Unit) {
        val toBeMapped = FileShareArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.backupFileShare = mapped
    }

    /**
     * @param value Databases to migrate
     */
    @JvmName("mwqdljdcdvetfbnm")
    public suspend fun selectedDatabases(`value`: List<MigrateSqlServerSqlMIDatabaseInputArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("csieucybfuvgyrji")
    public suspend
    fun selectedDatabases(argument: List<suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("wupoyiidummrvtyd")
    public suspend fun selectedDatabases(
        vararg
        argument: suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("qwmhtilvsudufkku")
    public suspend
    fun selectedDatabases(argument: suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param values Databases to migrate
     */
    @JvmName("wjyfshgmcvagqgvy")
    public suspend fun selectedDatabases(vararg values: MigrateSqlServerSqlMIDatabaseInputArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectedDatabases = mapped
    }

    /**
     * @param value Connection information for source SQL Server
     */
    @JvmName("odfiqnatexpiynof")
    public suspend fun sourceConnectionInfo(`value`: SqlConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceConnectionInfo = mapped
    }

    /**
     * @param argument Connection information for source SQL Server
     */
    @JvmName("wjmhccpvratcxebu")
    public suspend
    fun sourceConnectionInfo(argument: suspend SqlConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = SqlConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sourceConnectionInfo = mapped
    }

    /**
     * @param value Fully qualified resourceId of storage
     */
    @JvmName("cufwlmllsnnodeqc")
    public suspend fun storageResourceId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageResourceId = mapped
    }

    /**
     * @param value Connection information for Azure SQL Database Managed Instance
     */
    @JvmName("gsrjefgtfpmcmycy")
    public suspend fun targetConnectionInfo(`value`: MiSqlConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targetConnectionInfo = mapped
    }

    /**
     * @param argument Connection information for Azure SQL Database Managed Instance
     */
    @JvmName("wpcsesghchmulwxj")
    public suspend
    fun targetConnectionInfo(argument: suspend MiSqlConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = MiSqlConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.targetConnectionInfo = mapped
    }

    internal fun build(): ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs =
        ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs(
            azureApp = azureApp ?: throw PulumiNullFieldException("azureApp"),
            backupFileShare = backupFileShare,
            selectedDatabases = selectedDatabases ?: throw PulumiNullFieldException("selectedDatabases"),
            sourceConnectionInfo = sourceConnectionInfo ?: throw
                PulumiNullFieldException("sourceConnectionInfo"),
            storageResourceId = storageResourceId ?: throw PulumiNullFieldException("storageResourceId"),
            targetConnectionInfo = targetConnectionInfo ?: throw
                PulumiNullFieldException("targetConnectionInfo"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Input for task that migrates SQL Server databases to Azure SQL Database Managed Instance online scenario.
 * @property azureApp Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
 * @property backupFileShare Backup file share information for all selected databases.
 * @property selectedDatabases Databases to migrate
 * @property sourceConnectionInfo Connection information for source SQL Server
 * @property storageResourceId Fully qualified resourceId of storage
 * @property targetConnectionInfo Connection information for Azure SQL Database Managed Instance
 */
public data class ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs(
    public val azureApp: Output<AzureActiveDirectoryAppArgs>,
    public val backupFileShare: Output<FileShareArgs>? = null,
    public val selectedDatabases: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>,
    public val sourceConnectionInfo: Output<SqlConnectionInfoArgs>,
    public val storageResourceId: Output<String>,
    public val targetConnectionInfo: Output<MiSqlConnectionInfoArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs =
        com.pulumi.azurenative.datamigration.inputs.ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs.builder()
            .azureApp(azureApp.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .backupFileShare(backupFileShare?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .selectedDatabases(
                selectedDatabases.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .sourceConnectionInfo(
                sourceConnectionInfo.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .storageResourceId(storageResourceId.applyValue({ args0 -> args0 }))
            .targetConnectionInfo(
                targetConnectionInfo.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs].
 */
@PulumiTagMarker
public class ValidateMigrationInputSqlServerSqlMISyncTaskInputArgsBuilder internal constructor() {
    private var azureApp: Output<AzureActiveDirectoryAppArgs>? = null

    private var backupFileShare: Output<FileShareArgs>? = null

    private var selectedDatabases: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>? = null

    private var sourceConnectionInfo: Output<SqlConnectionInfoArgs>? = null

    private var storageResourceId: Output<String>? = null

    private var targetConnectionInfo: Output<MiSqlConnectionInfoArgs>? = null

    /**
     * @param value Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
     */
    @JvmName("nircnrwhchurmcyb")
    public suspend fun azureApp(`value`: Output<AzureActiveDirectoryAppArgs>) {
        this.azureApp = value
    }

    /**
     * @param value Backup file share information for all selected databases.
     */
    @JvmName("kupflpyxyaqkiima")
    public suspend fun backupFileShare(`value`: Output<FileShareArgs>) {
        this.backupFileShare = value
    }

    /**
     * @param value Databases to migrate
     */
    @JvmName("mdecaifbqtpurctw")
    public suspend
    fun selectedDatabases(`value`: Output<List<MigrateSqlServerSqlMIDatabaseInputArgs>>) {
        this.selectedDatabases = value
    }

    @JvmName("wccbbmnkmpqutxvq")
    public suspend fun selectedDatabases(
        vararg
        values: Output<MigrateSqlServerSqlMIDatabaseInputArgs>,
    ) {
        this.selectedDatabases = Output.all(values.asList())
    }

    /**
     * @param values Databases to migrate
     */
    @JvmName("asqpnlvwrtllkvlh")
    public suspend
    fun selectedDatabases(values: List<Output<MigrateSqlServerSqlMIDatabaseInputArgs>>) {
        this.selectedDatabases = Output.all(values)
    }

    /**
     * @param value Connection information for source SQL Server
     */
    @JvmName("tjfgbaciimobijfx")
    public suspend fun sourceConnectionInfo(`value`: Output<SqlConnectionInfoArgs>) {
        this.sourceConnectionInfo = value
    }

    /**
     * @param value Fully qualified resourceId of storage
     */
    @JvmName("nornbeclkcegifnw")
    public suspend fun storageResourceId(`value`: Output<String>) {
        this.storageResourceId = value
    }

    /**
     * @param value Connection information for Azure SQL Database Managed Instance
     */
    @JvmName("babtncgurmvsxsno")
    public suspend fun targetConnectionInfo(`value`: Output<MiSqlConnectionInfoArgs>) {
        this.targetConnectionInfo = value
    }

    /**
     * @param value Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
     */
    @JvmName("nydhboqssrryffws")
    public suspend fun azureApp(`value`: AzureActiveDirectoryAppArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azureApp = mapped
    }

    /**
     * @param argument Azure Active Directory Application the DMS instance will use to connect to the target instance of Azure SQL Database Managed Instance and the Azure Storage Account
     */
    @JvmName("glxblmapgaoioljm")
    public suspend fun azureApp(argument: suspend AzureActiveDirectoryAppArgsBuilder.() -> Unit) {
        val toBeMapped = AzureActiveDirectoryAppArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureApp = mapped
    }

    /**
     * @param value Backup file share information for all selected databases.
     */
    @JvmName("kfhvgiotbmaasqnv")
    public suspend fun backupFileShare(`value`: FileShareArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupFileShare = mapped
    }

    /**
     * @param argument Backup file share information for all selected databases.
     */
    @JvmName("pxtoejwtrccoycfk")
    public suspend fun backupFileShare(argument: suspend FileShareArgsBuilder.() -> Unit) {
        val toBeMapped = FileShareArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.backupFileShare = mapped
    }

    /**
     * @param value Databases to migrate
     */
    @JvmName("rvswqakdjysdxvak")
    public suspend fun selectedDatabases(`value`: List<MigrateSqlServerSqlMIDatabaseInputArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("knqhinprbsnmiuvr")
    public suspend
    fun selectedDatabases(argument: List<suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("yknwbwwbafdcgror")
    public suspend fun selectedDatabases(
        vararg
        argument: suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param argument Databases to migrate
     */
    @JvmName("htymivfanasycfcy")
    public suspend
    fun selectedDatabases(argument: suspend MigrateSqlServerSqlMIDatabaseInputArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            MigrateSqlServerSqlMIDatabaseInputArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.selectedDatabases = mapped
    }

    /**
     * @param values Databases to migrate
     */
    @JvmName("jrxpphyxhfaumqmf")
    public suspend fun selectedDatabases(vararg values: MigrateSqlServerSqlMIDatabaseInputArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectedDatabases = mapped
    }

    /**
     * @param value Connection information for source SQL Server
     */
    @JvmName("xuhrnolxqmxswsem")
    public suspend fun sourceConnectionInfo(`value`: SqlConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceConnectionInfo = mapped
    }

    /**
     * @param argument Connection information for source SQL Server
     */
    @JvmName("gidtnlyhchxiyhoc")
    public suspend
    fun sourceConnectionInfo(argument: suspend SqlConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = SqlConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sourceConnectionInfo = mapped
    }

    /**
     * @param value Fully qualified resourceId of storage
     */
    @JvmName("wypgauqdqfravwhc")
    public suspend fun storageResourceId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageResourceId = mapped
    }

    /**
     * @param value Connection information for Azure SQL Database Managed Instance
     */
    @JvmName("nuxdoblvtngprodt")
    public suspend fun targetConnectionInfo(`value`: MiSqlConnectionInfoArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targetConnectionInfo = mapped
    }

    /**
     * @param argument Connection information for Azure SQL Database Managed Instance
     */
    @JvmName("arqtnhnnfjencotl")
    public suspend
    fun targetConnectionInfo(argument: suspend MiSqlConnectionInfoArgsBuilder.() -> Unit) {
        val toBeMapped = MiSqlConnectionInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.targetConnectionInfo = mapped
    }

    internal fun build(): ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs =
        ValidateMigrationInputSqlServerSqlMISyncTaskInputArgs(
            azureApp = azureApp ?: throw PulumiNullFieldException("azureApp"),
            backupFileShare = backupFileShare,
            selectedDatabases = selectedDatabases ?: throw PulumiNullFieldException("selectedDatabases"),
            sourceConnectionInfo = sourceConnectionInfo ?: throw
                PulumiNullFieldException("sourceConnectionInfo"),
            storageResourceId = storageResourceId ?: throw PulumiNullFieldException("storageResourceId"),
            targetConnectionInfo = targetConnectionInfo ?: throw
                PulumiNullFieldException("targetConnectionInfo"),
        )
}
